==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppApplicationSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [WebAppApplicationSettings].
 */
@PulumiTagMarker
public class WebAppApplicationSettingsResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppApplicationSettingsArgs = WebAppApplicationSettingsArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebAppApplicationSettingsArgsBuilder.() -> Unit) {
        val builder = WebAppApplicationSettingsArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): WebAppApplicationSettings {
        val builtJavaResource =
            com.pulumi.azurenative.web.WebAppApplicationSettings(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebAppApplicationSettings(builtJavaResource)
    }
}

/**
 * String dictionary resource.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Example Usage
 * ### Update App Settings
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var webAppApplicationSettings = new AzureNative.Web.WebAppApplicationSettings("webAppApplicationSettings", new()
 *     {
 *         Name = "sitef6141",
 *         Properties =
 *         {
 *             { "Setting1", "Value1" },
 *             { "Setting2", "Value2" },
 *         },
 *         ResourceGroupName = "testrg123",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/web/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := web.NewWebAppApplicationSettings(ctx, "webAppApplicationSettings", &web.WebAppApplicationSettingsArgs{
 * 			Name: pulumi.String("sitef6141"),
 * 			Properties: pulumi.StringMap{
 * 				"Setting1": pulumi.String("Value1"),
 * 				"Setting2": pulumi.String("Value2"),
 * 			},
 * 			ResourceGroupName: pulumi.String("testrg123"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.web.WebAppApplicationSettings;
 * import com.pulumi.azurenative.web.WebAppApplicationSettingsArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var webAppApplicationSettings = new WebAppApplicationSettings("webAppApplicationSettings", WebAppApplicationSettingsArgs.builder()
 *             .name("sitef6141")
 *             .properties(Map.ofEntries(
 *                 Map.entry("Setting1", "Value1"),
 *                 Map.entry("Setting2", "Value2")
 *             ))
 *             .resourceGroupName("testrg123")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppApplicationSettings appsettings /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/config/appsettings
 * ```
 */
public class WebAppApplicationSettings internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppApplicationSettings,
) : KotlinCustomResource(javaResource, WebAppApplicationSettingsMapper) {
    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Settings.
     */
    public val properties: Output<Map<String, String>>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.key.to(args0.value)
            }).toMap()
        })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppApplicationSettingsMapper : ResourceMapper<WebAppApplicationSettings> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppApplicationSettings::class == javaResource::class

    override fun map(javaResource: Resource): WebAppApplicationSettings =
        WebAppApplicationSettings(
            javaResource as
                com.pulumi.azurenative.web.WebAppApplicationSettings,
        )
}

/**
 * @see [WebAppApplicationSettings].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppApplicationSettings].
 */
public suspend fun webAppApplicationSettings(
    name: String,
    block: suspend WebAppApplicationSettingsResourceBuilder.() -> Unit,
): WebAppApplicationSettings {
    val builder = WebAppApplicationSettingsResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppApplicationSettings].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppApplicationSettings(name: String): WebAppApplicationSettings {
    val builder = WebAppApplicationSettingsResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppApplicationSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [WebAppApplicationSettings].
 */
@PulumiTagMarker
public class WebAppApplicationSettingsResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppApplicationSettingsArgs = WebAppApplicationSettingsArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebAppApplicationSettingsArgsBuilder.() -> Unit) {
        val builder = WebAppApplicationSettingsArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): WebAppApplicationSettings {
        val builtJavaResource =
            com.pulumi.azurenative.web.WebAppApplicationSettings(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebAppApplicationSettings(builtJavaResource)
    }
}

/**
 * String dictionary resource.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Example Usage
 * ### Update App Settings
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var webAppApplicationSettings = new AzureNative.Web.WebAppApplicationSettings("webAppApplicationSettings", new()
 *     {
 *         Name = "sitef6141",
 *         Properties =
 *         {
 *             { "Setting1", "Value1" },
 *             { "Setting2", "Value2" },
 *         },
 *         ResourceGroupName = "testrg123",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/web/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := web.NewWebAppApplicationSettings(ctx, "webAppApplicationSettings", &web.WebAppApplicationSettingsArgs{
 * 			Name: pulumi.String("sitef6141"),
 * 			Properties: pulumi.StringMap{
 * 				"Setting1": pulumi.String("Value1"),
 * 				"Setting2": pulumi.String("Value2"),
 * 			},
 * 			ResourceGroupName: pulumi.String("testrg123"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.web.WebAppApplicationSettings;
 * import com.pulumi.azurenative.web.WebAppApplicationSettingsArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var webAppApplicationSettings = new WebAppApplicationSettings("webAppApplicationSettings", WebAppApplicationSettingsArgs.builder()
 *             .name("sitef6141")
 *             .properties(Map.ofEntries(
 *                 Map.entry("Setting1", "Value1"),
 *                 Map.entry("Setting2", "Value2")
 *             ))
 *             .resourceGroupName("testrg123")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppApplicationSettings appsettings /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/config/appsettings
 * ```
 */
public class WebAppApplicationSettings internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppApplicationSettings,
) : KotlinCustomResource(javaResource, WebAppApplicationSettingsMapper) {
    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Settings.
     */
    public val properties: Output<Map<String, String>>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.key.to(args0.value)
            }).toMap()
        })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppApplicationSettingsMapper : ResourceMapper<WebAppApplicationSettings> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppApplicationSettings::class == javaResource::class

    override fun map(javaResource: Resource): WebAppApplicationSettings =
        WebAppApplicationSettings(
            javaResource as
                com.pulumi.azurenative.web.WebAppApplicationSettings,
        )
}

/**
 * @see [WebAppApplicationSettings].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppApplicationSettings].
 */
public suspend fun webAppApplicationSettings(
    name: String,
    block: suspend WebAppApplicationSettingsResourceBuilder.() -> Unit,
): WebAppApplicationSettings {
    val builder = WebAppApplicationSettingsResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppApplicationSettings].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppApplicationSettings(name: String): WebAppApplicationSettings {
    val builder = WebAppApplicationSettingsResourceBuilder()
    builder.name(name)
    return builder.build()
}
